@@ -1,4 +1,4 @@
-"""Constants used throughout the class generator."""
+"""Constants used throughout the class generator and schema utilities."""
 
 import keyword
 from pathlib import Path
@@ -11,6 +11,8 @@ FIELDS_STR: str = "FIELDS"
 TESTS_MANIFESTS_DIR: Path = Path("class_generator") / "tests" / "manifests"
 SCHEMA_DIR: Path = Path("class_generator") / "schema"
 RESOURCES_MAPPING_FILE: Path = SCHEMA_DIR / "__resources-mappings.json"
+RESOURCES_MAPPING_ARCHIVE: Path = SCHEMA_DIR / "__resources-mappings.json.gz"
+DEFINITIONS_FILE: Path = SCHEMA_DIR / "_definitions.json"
 
 # Description constants
 MISSING_DESCRIPTION_STR: str = "No field description from API"
